==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/pt/templates.php <==
<?php
regGS("The template $1 is in use and can not be deleted.", "O modelo $1 está a ser usado e não pode ser eliminado.");
regGS("The folder could not be deleted.", "A pasta não pode ser eliminada");
regGS("The directory must be empty", "A pasta tem de estar vazia.");
regGS("Create new folder", "Criar Pasta");
regGS("Upload template", "Transferir Modelo");
regGS("Creating new folder", "Criando Pasta");
regGS("You do not have the right to create new folders.", "Não tem permissões para criar Pastas");
regGS("The folder $1 could not be created", "A pasta $1 não pode ser criada");
regGS("A file or folder having the name $1 already exists", "Um ficheiro ou pasta com este nome já existe.");
regGS("You do not have the right to delete templates.", "Não tem permissões para eliminar modelos");
regGS("Are you sure you want to delete the folder $1 from $2?", "Deseja eliminar pasta $1 de $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Deseja eliminar o modelo $1 de $2?");
regGS("Deleting template", "Eliminando modelo");
regGS("Deleting folder", "Eliminando pasta");
regGS("Template $1 was deleted", "O modelo $1 foi eliminado.");
regGS("Delete folder", "Eliminar pasta");
regGS("Folders", "Pastas");
regGS("No folders.", "Não existem pastas");
regGS("Files", "Ficheiros");
regGS("No templates.", "Não existem modelos");
regGS("Uploading template", "Transferindo Modelo");
regGS("File", "Ficheiro");
regGS("Create new template", "Criar Modelo");
regGS("Creating new template", "Criando Modelo");
regGS("Duplicate template", "Duplicar Modelo");
regGS("Edit template", "Editar Modelo");
regGS("The template $1 has been created.", "O modelo $1 foi criado");
regGS("Do you want to edit the template ?", "Editar modelo?");
regGS("The template $1 could not be created.", "O modelo $1 não pode ser criado");
regGS("Template $1 was changed", "O modelo $1 foi alterado");
regGS("New template $1 was created", "Modelo $1 foi criado");
regGS("Template $1 was duplicated into $2", "Modelo $1 foi duplicado para $2");
regGS("Template charset", "Código de Cahracteres do Modelo");
regGS("Select a language/character set", "Escolha o Idioma/Código de Caracteres");
regGS("All languages", "Todos os idiomas");
regGS("You do not have the right to modify templates.", "Não tem permissões para alterar modelos.");
regGS("Invalid template file $1", "Ficheiro de modelo $1 inválido");
regGS("You do not have the right to create folders.", "Não tem permissões para criar pastas.");
regGS("You do not have the right to upload templates.", "Não tem permissões para transferir modelos.");
regGS("You do not have the right to create templates.", "Não tem permissões para criar modelos.");
regGS("Duplicate file", "Duplicar ficheiro");
regGS("Delete file", "Eliminar ficheiro");
regGS("Unable to save the template '$1' to the path '$2'.", "Não é possivel guardar o modelo '$1' em '$2'.");
regGS("Please check if the user '$1' has permission to write in this directory.", "Verifique se o utilizador '$1' tem permissões para escrever na pasta.");
regGS("Unable to delete the template '$1' in the path '$2'.", "Não é possivél eliminar o modelo '$1' de '$2'");
regGS("The folder has been deleted.", "A pasta foi eliminada");
regGS("The template has been deleted.", "O modelo foi eliminado");
regGS("The template could not be deleted.", "O modelo não pode ser eliminado");
regGS("Save", "Gravar");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/pt/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "O Modelo $1 foi guardado com sucesso.");
regGS("The template $1 is in use and can not be deleted.", "O modelo $1 está a ser usado e não pode ser eliminado.");
regGS("Create new folder", "Criar Pasta");
regGS("Upload template", "Transferir Modelo");
regGS("You do not have the right to create new folders.", "Não tem permissões para criar Pastas");
regGS("A file or folder having the name $1 already exists", "Um ficheiro ou pasta com este nome já existe.");
regGS("You do not have the right to delete templates.", "Não tem permissões para eliminar modelos");
regGS("Are you sure you want to delete the folder $1 from $2?", "Deseja eliminar pasta $1 de $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Deseja eliminar o modelo $1 de $2?");
regGS("Template $1 was deleted", "O modelo $1 foi eliminado.");
regGS("Delete folder", "Eliminar pasta");
regGS("Folders", "Pastas");
regGS("No folders.", "Não existem pastas");
regGS("Files", "Ficheiros");
regGS("No templates.", "Não existem modelos");
regGS("File", "Ficheiro");
regGS("Create new template", "Criar Modelo");
regGS("Duplicate template", "Duplicar Modelo");
regGS("Edit template", "Editar Modelo");
regGS("The template $1 could not be created.", "O modelo $1 não pode ser criado");
regGS("Template $1 was changed", "O modelo $1 foi alterado");
regGS("Template $1 was duplicated into $2", "Modelo $1 foi duplicado para $2");
regGS("Template charset", "Código de Cahracteres do Modelo");
regGS("Select a language/character set", "Escolha o Idioma/Código de Caracteres");
regGS("All languages", "Todos os idiomas");
regGS("You do not have the right to modify templates.", "Não tem permissões para alterar modelos.");
regGS("Invalid template file $1", "Ficheiro de modelo $1 inválido");
regGS("You do not have the right to create folders.", "Não tem permissões para criar pastas.");
regGS("You do not have the right to upload templates.", "Não tem permissões para transferir modelos.");
regGS("You do not have the right to create templates.", "Não tem permissões para criar modelos.");
regGS("Duplicate file", "Duplicar ficheiro");
regGS("Delete file", "Eliminar ficheiro");
regGS("Please check if the user '$1' has permission to write in this directory.", "Verifique se o utilizador '$1' tem permissões para escrever na pasta.");
regGS("The folder has been deleted.", "A pasta foi eliminada");
regGS("The template has been deleted.", "O modelo foi eliminado");
regGS("The template could not be deleted.", "O modelo não pode ser eliminado");
regGS("Save", "Gravar");
?>
